# frozen_string_literal: true

require_relative 'referenced_object'

class DistributedPress
  module V1
    module Social
      # A Collection or OrderedCollection is a an object with a list of
      # items. Sometimes, collections are paginated, so we provide
      # methods to traverse them.
      class Collection < ReferencedObject
        include Enumerable

        RECURSIVE_ATTRIBUTES = %w[items orderedItems first next].freeze

        # If the Collection has items, yield them and keep processing
        # any pages forward until the end.
        #
        # @todo Use totalItems from the starting object for validation
        # @todo Implement lazy loading
        def each(&block)
          Enumerator.new do |enum|
            RECURSIVE_ATTRIBUTES.each do |attribute|
              next unless object.key?(attribute)

              object[attribute].each(&block).each do |item|
                enum << item
              end
            end
          end
        end
      end
    end
  end
end
