# frozen_string_literal: true

class DistributedPress
  module V1
    module Social
      # An object with external references
      #
      # @todo Merge with Reference
      class ReferencedObject
        extend Forwardable

        REFERENTIABLE_ATTRIBUTES =
          %w[
            actor
            owner
            attributedTo
            cc
            inReplyTo
            object
            replies
            to
            publicKey
            audience

            alsoKnownAs
            devices
            featured
            featuredTags
            followers
            following
            inbox
            movedTo
            outbox

            first
            items
            next
            orderedItems
            partOf
            prev
          ].freeze

        attr_reader :object
        attr_reader :dereferencer
        attr_reader :referenced

        def_delegators :referenced, :[], :dig, :to_h, :to_json

        def initialize(object:, dereferencer:)
          @object = object
          @dereferencer = dereferencer
          @referenced = HTTParty::ModuleInheritableAttributes.hash_deep_dup(object)
          reference_object! referenced
        end

        def _dump(_)
          Marshal.dump([object, dereferencer])
        end

        def self._load(array)
          object, dereferencer = Marshal.load(array)

          new(object: object, dereferencer: dereferencer)
        end

        private

        def reference_object!(object)
          REFERENTIABLE_ATTRIBUTES.each do |attribute|
            next unless object.key? attribute

            case object[attribute]
            when Array
              object[attribute].map! do |o|
                case o
                when Hash
                  reference_object!(o)
                  o
                when String
                  if o == DistributedPress::V1::Social::Reference::PUBLIC
                    o
                  else
                    dereferencer.references(dereferencer.uris(o))
                  end
                else
                  o
                end
              end
            when Hash
              reference_object!(object[attribute])
            when String
              unless object[attribute] == DistributedPress::V1::Social::Reference::PUBLIC
                object[attribute] = dereferencer.references(dereferencer.uris(object[attribute]))
              end
            end
          end
        end
      end
    end
  end
end
