# frozen_string_literal: true

require 'uri'
require_relative 'client'

class DistributedPress
  module V1
    module Social
      # Manages the activity's replies
      class Replies
        # @return [DistributedPress::V1::Social::Client]
        attr_reader :client

        # @return [String]
        attr_reader :actor

        # @return [String] Activity ID (URL)
        attr_reader :activity

        # @param :client [DistributedPress::V1::Social::Client]
        # @param :actor [String]
        # @param :activity [String]
        def initialize(client:, actor:, activity:)
          @client = client
          @actor = actor
          @activity = activity
        end

        # Get the activities replies collection. Authenticated requests
        # contain the list of replies.
        #
        # @return [HTTParty::Response]
        def get
          client.get(endpoint: endpoint)
        end

        # Replies
        #
        # @return [String]
        def endpoint
          @endpoint ||= "/v1/#{actor}/inbox/replies/#{URI.encode_uri_component(activity)}"
        end
      end
    end
  end
end
